.. Copyright by The HDF Group.
 All rights reserved.

 This file is part of the HDF Compass Viewer. The full HDF Compass
 copyright notice, including terms governing use, modification, and
 terms governing use, modification, and redistribution, is contained in
 the file COPYING, which can be found at the root of the source code
 distribution tree.  If you do not have access to this file, you may
 request a copy from help@hdfgroup.org.

HDF Compass's documentation
===========================

This document provide information about the HDF Compass application.

In Brief
--------

HDF Compass is an experimental viewer program for
HDF5 and related formats, designed to complement other more complex
applications like HDFView.  Strong emphasis is placed on clean minimal design,
and maximum extensibility through a plugin system for new formats.

HDF Compass is written in Python, but ships as a native application on
Windows, OS X, and Linux, by using PyInstaller and Py2App to package the app.


Contents
--------

.. toctree::
   :maxdepth: 2

   requirements
   license
   how_to_install
   how_to_use
   how_to_contribute
   data_model
   how_to_release
   how_to_freeze

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

